@@ -1,5 +1,16 @@
 #if 0
 
+N_("Henry's Goulash")
+N_("Originally from Hungary, this dish is widespread in Central Europe.")
+N_("This is my friend Henry's version of it.")
+N_("Chop very minutely onions and garlic. Cut the meat in chunks. Chop red bell peppers in small squares.")
+N_("Cook first the meat, alone without salt or spices.  Keep it warm in a separated bowl.")
+N_("Fry in a mixture of butter and oil half of each pepper, onions and garlic.  When this is soft, add the tomato paste.")
+N_("When everything is almost ready, add meat, wine, spices and bay leaves.  ")
+N_("Put everything in the oven at a low temperature and cook it for some two hours.")
+N_("Meantime the goulash is in the oven, chop the potatoes in sledges and cook them with salt & pepper.")
+N_("Serve warm together.")
+N_("If you don't have or don't want potatoes, you can use pasta instead.")
 N_("Borscht")
 N_("This is a traditional soup from East and Central Europe. There are an Ukrainian/Russian and a Polish version, but both a very similar so I put them together in a general recipe.")
 N_("[image:0]Over an open flame or under a broiler, roast 1 carrot and half of the onion until charred, about 3 minutes.")
@@ -21,13 +32,18 @@ N_("[image:0]Mix well. Cover with lid(s), and place in the refrigerator for at l
 N_("[image:1]You can make ahead, but best to consume within 2-3 days.")
 N_("Carbonara")
 N_("\"Carbonara\" is a sauce that can be used with long pasta, like spaghetti or fettuccine.")
-N_("[image:1]Start by boiling about 1 litre of water for each 100g of pasta.")
-N_("[image:1]Once the water is boiling, pour 20g of coarse salt in it for every litre of water, and then throw the spaghetti in.")
-N_("[image:1]While the pasta is cooking, take a large bowl and put the parmesan cheese in it.")
-N_("[image:2]Add the whole egg and the yolks to the parmesan, and beat the eggs until you get a creamy sauce.")
-N_("[image:3]Put the guanciale in a small pan with a teaspoon of oil, and shallow fry it until the fat is transparent and the meat is crispy; then remove from the fire.")
-N_("[image:5]Once the pasta is ready, drain it and add it to the eggs and cheese. Then, add the guanciale.")
-N_("[image:6]Season with salt and pepper to your liking.")
+N_("Start by boiling about 1 litre of water for each 100g of pasta.")
+N_("[image:1]")
+N_("Once the water is boiling, pour 20g of coarse salt in it for every litre of water, and then throw the spaghetti in.")
+N_("While the pasta is cooking, take a large bowl and put the parmesan cheese in it.")
+N_("[image:2]")
+N_("Add the whole egg and the yolks to the parmesan, and beat the eggs until you get a creamy sauce.")
+N_("[image:3]")
+N_("Put the guanciale in a small pan with a teaspoon of oil, and shallow fry it until the fat is transparent and the meat is crispy; then remove from the fire.")
+N_("[image:5]")
+N_("Once the pasta is ready, drain it and add it to the eggs and cheese. Then, add the guanciale.")
+N_("[image:6]")
+N_("Season with salt and pepper to your liking.")
 N_("If you cannot find guanciale (cured pork cheek) you can substitute it with pancetta.")
 N_("Classic Chicken Noodle Soup")
 N_("A simple take on a typical American meal.")
