@@ -32,7 +32,7 @@
 #include "gr-cuisine.h"
 #include "gr-shell-search-provider.h"
 #include "gr-utils.h"
-#include "gr-recipe-exporter.h"
+#include "gr-logging.h"
 
 
 struct _GrApp
@@ -40,8 +40,6 @@ struct _GrApp
         GtkApplication parent_instance;
 
         GrShellSearchProvider *search_provider;
-        GrRecipeExporter *exporter;
-
         GtkCssProvider *css_provider;
 };
 
@@ -113,18 +111,6 @@ about_activated (GSimpleAction *action,
         gr_window_show_about_dialog (GR_WINDOW (win));
 }
 
-static void
-report_issue_activated (GSimpleAction *action,
-                 GVariant      *parameter,
-                 gpointer       app)
-{
-        GtkWindow *win;
-
-        gr_app_activate (G_APPLICATION (app));
-        win = gtk_application_get_active_window (GTK_APPLICATION (app));
-        gr_window_show_report_issue (GR_WINDOW (win));
-}
-
 static void
 news_activated (GSimpleAction *action,
                 GVariant      *parameter,
@@ -137,18 +123,6 @@ news_activated (GSimpleAction *action,
         gr_window_show_news (GR_WINDOW (win));
 }
 
-static void
-quit_activated (GSimpleAction *action,
-                GVariant      *parameter,
-                gpointer       app)
-{
-        GtkWindow *win;
-
-        gr_app_activate (G_APPLICATION (app));
-        win = gtk_application_get_active_window (GTK_APPLICATION (app));
-        gtk_window_close (win);
-}
-
 static void
 import_activated (GSimpleAction *action,
                   GVariant      *parameter,
@@ -207,60 +181,28 @@ search_activated (GSimpleAction *action,
         gr_window_show_search (GR_WINDOW (win), search);
 }
 
-#define DEFAULT_LEVELS (G_LOG_LEVEL_ERROR | G_LOG_LEVEL_CRITICAL | G_LOG_LEVEL_WARNING | G_LOG_LEVEL_MESSAGE)
-#define INFO_LEVELS (G_LOG_LEVEL_INFO | G_LOG_LEVEL_DEBUG)
-
-static gboolean verbose_logging;
-
-/* verbose_logging turns enables DEBUG and INFO messages just for our log domain.
- * We also respect the G_MESSAGES_DEBUG environment variable.
- */
-static GLogWriterOutput
-log_writer (GLogLevelFlags   log_level,
-            const GLogField *fields,
-            gsize            n_fields,
-            gpointer         user_data)
+static void
+quit_activated (GSimpleAction *action,
+                GVariant      *parameter,
+                gpointer       app)
 {
-        if (!(log_level & DEFAULT_LEVELS)) {
-                const gchar *domains, *log_domain = NULL;
-                gsize i;
+        GtkWindow *win;
 
-                domains = g_getenv ("G_MESSAGES_DEBUG");
+        gr_app_activate (G_APPLICATION (app));
+        win = gtk_application_get_active_window (GTK_APPLICATION (app));
+        gtk_window_close (win);
+}
 
-                if (verbose_logging && domains == NULL)
-                        domains = G_LOG_DOMAIN;
+static void
+report_issue_activated (GSimpleAction *action,
+                        GVariant      *parameter,
+                        gpointer       app)
+{
+        GtkWindow *win;
 
-                if ((log_level & INFO_LEVELS) == 0 || domains == NULL)
-                        return G_LOG_WRITER_HANDLED;
-
-                for (i = 0; i < n_fields; i++) {
-                        if (g_strcmp0 (fields[i].key, "GLIB_DOMAIN") == 0) {
-                                log_domain = fields[i].value;
-                                break;
-                        }
-                }
-
-                if (!verbose_logging || strcmp (log_domain, G_LOG_DOMAIN) != 0) {
-                        if (strcmp (domains, "all") != 0 &&
-                            (log_domain == NULL || !strstr (domains, log_domain)))
-                                return G_LOG_WRITER_HANDLED;
-                }
-        }
-
-        if (g_log_writer_is_journald (fileno (stderr)) &&
-            g_log_writer_journald (log_level, fields, n_fields, user_data) == G_LOG_WRITER_HANDLED)
-                goto handled;
-
-        if (g_log_writer_standard_streams (log_level, fields, n_fields, user_data) == G_LOG_WRITER_HANDLED)
-                goto handled;
-
-        return G_LOG_WRITER_UNHANDLED;
-
-handled:
-        if (log_level & G_LOG_LEVEL_ERROR)
-                g_abort ();
-
-        return G_LOG_WRITER_HANDLED;
+        gr_app_activate (G_APPLICATION (app));
+        win = gtk_application_get_active_window (GTK_APPLICATION (app));
+        gr_window_show_report_issue (GR_WINDOW (win));
 }
 
 static void
@@ -268,7 +210,10 @@ verbose_logging_activated (GSimpleAction *action,
                            GVariant      *parameter,
                            gpointer       application)
 {
-        g_variant_get (parameter, "b", &verbose_logging);
+        gboolean verbose;
+
+        g_variant_get (parameter, "b", &verbose);
+        gr_set_verbose_logging (verbose);
 }
 
 static GActionEntry app_entries[] =
@@ -287,22 +232,61 @@ static GActionEntry app_entries[] =
 };
 
 static void
-load_application_css (GrApp *app)
+setup_actions_and_accels (GApplication *application)
 {
+	struct {
+		const char *detailed_action;
+		const char *accelerators[2];
+	} accels[] = {
+		{ "app.quit",       { "<Primary>q", NULL } },
+		{ "app.search('')", { "<Primary>f", NULL } },
+		{ "win.copy",       { "<Primary>c", NULL } },
+		{ "win.paste",      { "<Primary>v", NULL } },
+	};
+        int i;
+
+        g_action_map_add_action_entries (G_ACTION_MAP (application),
+                                         app_entries, G_N_ELEMENTS (app_entries),
+                                         application);
+
+#ifndef ENABLE_AUTOAR
+        {
+                GAction *action;
+
+                action = g_action_map_lookup_action (G_ACTION_MAP (application), "import");
+                g_object_set (action, "enabled", FALSE, NULL);
+        }
+#endif
+
+        for (i = 0; i < G_N_ELEMENTS (accels); i++)
+                gtk_application_set_accels_for_action (GTK_APPLICATION (application),
+                                                       accels[i].detailed_action,
+                                                       accels[i].accelerators);
+}
+
+static void
+load_application_menu (GApplication *application)
+{
+        g_autoptr(GtkBuilder) builder = NULL;
+        GObject *menu;
+
+        builder = gtk_builder_new_from_resource ("/org/gnome/Recipes/menus.ui");
+        if (strcmp (G_OBJECT_TYPE_NAME (gdk_display_get_default ()), "GdkQuartzDisplay") == 0) {
+                menu = gtk_builder_get_object (builder, "menubar");
+                gtk_application_set_menubar (GTK_APPLICATION (application), G_MENU_MODEL (menu));
+        }
+        else {
+                menu = gtk_builder_get_object (builder, "app-menu");
+                gtk_application_set_app_menu (GTK_APPLICATION (application), G_MENU_MODEL (menu));
+        }
+}
+
+static void
+load_application_css (GApplication *application)
+{
+        GrApp *app = GR_APP (application);
         gboolean dark;
-        const char *css_file[2] = {
-                "recipes-light.css",
-                "recipes-dark.css"
-        };
-        const char *src_file[2] = {
-                "src/recipes-light.css",
-                "src/recipes-dark.css"
-        };
-        const char *resource[2] = {
-                "resource:///org/gnome/Recipes/recipes-light.css",
-                "resource:///org/gnome/Recipes/recipes-dark.css"
-        };
-        const char *path;
+        g_autofree char *path = NULL;
         g_autofree char *css = NULL;
 
         if (!app->css_provider) {
@@ -315,14 +299,7 @@ load_application_css (GrApp *app)
                       "gtk-application-prefer-dark-theme", &dark,
                       NULL);
 
-        /* Let designers test css tweaks in the build tree without rebuilding */
-        if (g_file_test (css_file[dark], G_FILE_TEST_EXISTS))
-                path = css_file[dark];
-        else if (g_file_test (src_file[dark], G_FILE_TEST_EXISTS))
-                path = src_file[dark];
-        else
-                path = resource[dark];
-
+        path = g_strdup_printf ("resource:///org/gnome/Recipes/recipes-%s.css", dark ? "dark" : "light");
         g_info ("Loading application CSS from %s", path);
 
         css = gr_cuisine_get_css (path);
@@ -334,64 +311,22 @@ load_application_css (GrApp *app)
 }
 
 static void
-gr_app_startup (GApplication *app)
+gr_app_startup (GApplication *application)
 {
-	struct {
-		const char *detailed_action;
-		const char *accelerators[2];
-	} accels[] = {
-		{ "app.quit", { "<Primary>q", NULL } },
-		{ "app.search('')", { "<Primary>f", NULL } },
-		{ "win.copy", { "<Primary>c", NULL } },
-		{ "win.paste", { "<Primary>v", NULL } },
-	};
-	int i;
+        G_APPLICATION_CLASS (gr_app_parent_class)->startup (application);
 
-        G_APPLICATION_CLASS (gr_app_parent_class)->startup (app);
-
-        g_action_map_add_action_entries (G_ACTION_MAP (app),
-                                         app_entries, G_N_ELEMENTS (app_entries),
-                                         app);
-
-#ifndef ENABLE_AUTOAR
-        {
-                GAction *action;
-
-                action = g_action_map_lookup_action (G_ACTION_MAP (app), "import");
-                g_object_set (action, "enabled", FALSE, NULL);
-        }
-#endif
-
-	for (i = 0; i < G_N_ELEMENTS (accels); i++) {
-        	gtk_application_set_accels_for_action (GTK_APPLICATION (app),
-						       accels[i].detailed_action,
-						       accels[i].accelerators);
-        }
-
-        {
-                g_autoptr(GtkBuilder) builder = NULL;
-                GObject *menu;
-
-                builder = gtk_builder_new_from_resource ("/org/gnome/Recipes/menus.ui");
-                if (strcmp (G_OBJECT_TYPE_NAME (gdk_display_get_default ()), "GdkQuartzDisplay") == 0) {
-                        menu = gtk_builder_get_object (builder, "menubar");
-                        gtk_application_set_menubar (GTK_APPLICATION (app), G_MENU_MODEL (menu));
-                }
-                else {
-                        menu = gtk_builder_get_object (builder, "app-menu");
-                        gtk_application_set_app_menu (GTK_APPLICATION (app), G_MENU_MODEL (menu));
-                }
-         }
-
-        load_application_css (GR_APP (app));
+        setup_actions_and_accels (application);
+        load_application_menu (application);
+        load_application_css (application);
 }
 
 static void
-gr_app_open (GApplication  *app,
+gr_app_open (GApplication  *application,
              GFile        **files,
              gint           n_files,
              const char    *hint)
 {
+        GrApp *app = GR_APP (application);
         GtkWindow *win;
 
         if (n_files > 1)
@@ -399,7 +334,7 @@ gr_app_open (GApplication  *app,
 
         win = gtk_application_get_active_window (GTK_APPLICATION (app));
         if (!win) {
-                win = GTK_WINDOW (gr_window_new (GR_APP (app)));
+                win = GTK_WINDOW (gr_window_new (app));
                 gtk_window_present (win);
         }
 
@@ -409,15 +344,14 @@ gr_app_open (GApplication  *app,
 }
 
 static gboolean
-gr_app_dbus_register (GApplication    *application,
-                      GDBusConnection *connection,
-                      const gchar     *object_path,
-                      GError         **error)
+gr_app_dbus_register (GApplication     *application,
+                      GDBusConnection  *connection,
+                      const gchar      *object_path,
+                      GError          **error)
 {
         GrApp *app = GR_APP (application);
 
         app->search_provider = gr_shell_search_provider_new ();
-        gr_shell_search_provider_setup (app->search_provider, gr_recipe_store_get ());
 
         return gr_shell_search_provider_register (app->search_provider, connection, error);
 }
@@ -447,7 +381,7 @@ gr_app_init (GrApp *self)
                                        G_OPTION_FLAG_NONE, G_OPTION_ARG_NONE,
                                        _("Turn on verbose logging"), NULL);
 
-        g_log_set_writer_func (log_writer, NULL, NULL);
+        g_log_set_writer_func (gr_log_writer, NULL, NULL);
 }
 
 static int
