@@ -30,7 +30,6 @@
 #include "gr-chef-dialog.h"
 #include "gr-chef.h"
 #include "gr-recipe-store.h"
-#include "gr-app.h"
 #include "gr-window.h"
 #include "gr-utils.h"
 #include "gr-chef-tile.h"
@@ -202,7 +201,7 @@ save_chef_dialog (GrChefDialog  *self,
         gtk_text_buffer_get_bounds (buffer, &start, &end);
         description = gtk_text_buffer_get_text (buffer, &start, &end, FALSE);
 
-        store = gr_app_get_recipe_store (GR_APP (g_application_get_default ()));
+        store = gr_recipe_store_get ();
 
         if (id != NULL && id[0] != '\0'){
                 g_object_set (self->chef,
@@ -291,7 +290,7 @@ gr_chef_dialog_set_chef (GrChefDialog *self,
 
         revert_changes (self);
 
-        store = gr_app_get_recipe_store (GR_APP (g_application_get_default ()));
+        store = gr_recipe_store_get ();
 
         same_chef = self->chef != NULL && self->chef == chef;
 
@@ -433,7 +432,7 @@ populate_chef_list (GrChefDialog *dialog)
         guint length;
         int i;
 
-        store = gr_app_get_recipe_store (GR_APP (g_application_get_default ()));
+        store = gr_recipe_store_get ();
         keys = gr_recipe_store_get_chef_keys (store, &length);
 
         for (i = 0; keys[i]; i++) {
@@ -479,6 +478,10 @@ gr_chef_dialog_new (GrChef   *chef,
                                "use-header-bar", use_header_bar,
                                NULL);
 
+        gtk_widget_realize (GTK_WIDGET (dialog));
+        gdk_window_set_functions (gtk_widget_get_window (GTK_WIDGET (dialog)),
+                                  GDK_FUNC_ALL | GDK_FUNC_MINIMIZE | GDK_FUNC_MAXIMIZE);
+
         gr_chef_dialog_set_chef (dialog, chef);
         gr_chef_dialog_can_create (dialog, create);
 
