@@ -33,7 +33,6 @@
 #include "gr-chef.h"
 #include "gr-recipe.h"
 #include "gr-recipe-store.h"
-#include "gr-app.h"
 #include "gr-utils.h"
 #include "gr-mail.h"
 
@@ -127,6 +126,8 @@ cleanup_export (GrRecipeExporter *exporter)
         g_clear_object (&exporter->dest);
         g_list_free_full (exporter->sources, g_object_unref);
         exporter->sources = NULL;
+
+        gr_recipe_store_clear_export_list (gr_recipe_store_get ());
 }
 
 #ifdef ENABLE_AUTOAR
@@ -159,7 +160,7 @@ mail_done (GObject      *source,
         if (!gr_send_mail_finish (result, &error)) {
                 GObject *file_chooser;
 
-                g_message ("Sending mail failed: %s", error->message);
+                g_info ("Sending mail failed: %s", error->message);
 
                 file_chooser = (GObject *)gtk_file_chooser_native_new (_("Save the exported recipe"),
                                                                        GTK_WINDOW (exporter->window),
@@ -268,6 +269,8 @@ export_one_recipe (GrRecipeExporter  *exporter,
         const char *instructions;
         const char *notes;
         int serves;
+        int default_image;
+        int spiciness;
         GrDiets diets;
         GDateTime *ctime;
         GDateTime *mtime;
@@ -292,6 +295,8 @@ export_one_recipe (GrRecipeExporter  *exporter,
         notes = gr_recipe_get_notes (recipe);
         ctime = gr_recipe_get_ctime (recipe);
         mtime = gr_recipe_get_mtime (recipe);
+        default_image = gr_recipe_get_default_image (recipe);
+        spiciness = gr_recipe_get_spiciness (recipe);
 
         g_object_get (recipe, "images", &images, NULL);
 
@@ -331,7 +336,9 @@ export_one_recipe (GrRecipeExporter  *exporter,
         g_key_file_set_string (keyfile, key, "Instructions", instructions ? instructions : "");
         g_key_file_set_string (keyfile, key, "Notes", notes ? notes : "");
         g_key_file_set_integer (keyfile, key, "Serves", serves);
+        g_key_file_set_integer (keyfile, key, "Spiciness", spiciness);
         g_key_file_set_integer (keyfile, key, "Diets", diets);
+        g_key_file_set_integer (keyfile, key, "DefaultImage", default_image);
 
         g_key_file_set_string_list (keyfile, key, "Images", (const char * const *)paths, g_strv_length (paths));
 
@@ -411,7 +418,7 @@ prepare_export (GrRecipeExporter  *exporter,
         g_autoptr(GHashTable) chefs = NULL;
         g_autofree char *imagedir = NULL;
 
-        store = gr_app_get_recipe_store (GR_APP (g_application_get_default ()));
+        store = gr_recipe_store_get ();
 
         g_assert (exporter->dir == NULL);
         g_assert (exporter->sources == NULL);
@@ -517,10 +524,24 @@ do_export (GrRecipeExporter *exporter)
 {
         int i;
         g_autofree char *path = NULL;
+        int extra;
+        g_autofree char *name = NULL;
+
+        extra = g_list_length (exporter->recipes);
+        if (extra > 1)
+                name = g_strdup_printf ("%s (%d recipes)", gr_recipe_get_name (GR_RECIPE (exporter->recipes->data)), extra);
+        else
+                name = g_strdup (gr_recipe_get_name (GR_RECIPE (exporter->recipes->data)));
+        g_strdelimit (name, "./", ' ');
 
         for (i = 0; i < 1000; i++) {
                 g_autofree char *tmp;
-                tmp = g_strdup_printf ("%s/recipes%d.gnome-recipes-export", get_user_data_dir (), i);
+
+                if (i == 0)
+                        tmp = g_strdup_printf ("%s/%s.gnome-recipes-export", get_user_data_dir (), name);
+                else
+                        tmp = g_strdup_printf ("%s/%s(%d).gnome-recipes-export", get_user_data_dir (), name, i);
+
                 if (!g_file_test (tmp, G_FILE_TEST_EXISTS)) {
                         path = g_strdup (tmp);
                         break;
@@ -545,10 +566,10 @@ export_dialog_response (GtkWidget        *dialog,
                         GrRecipeExporter *exporter)
 {
         if (response_id == GTK_RESPONSE_CANCEL) {
-                g_message ("not exporting now");
+                g_info ("Not exporting now");
         }
         else if (response_id == GTK_RESPONSE_OK) {
-                g_message ("exporting %d recipes now", g_list_length (exporter->recipes));
+                g_info ("Exporting %d recipes now", g_list_length (exporter->recipes));
 
                 exporter->contribute = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (exporter->contribute_button));
 
@@ -614,18 +635,23 @@ row_activated (GtkListBox *list,
                GtkListBoxRow *row,
                GrRecipeExporter *exporter)
 {
+        GrRecipeStore *store;
         GrRecipe *recipe;
         GtkWidget *image;
 
+        store = gr_recipe_store_get ();
+
         recipe = GR_RECIPE (g_object_get_data (G_OBJECT (row), "recipe"));
         image = GTK_WIDGET (g_object_get_data (G_OBJECT (row), "check"));
 
         if (gtk_widget_get_opacity (image) > 0.5) {
+                gr_recipe_store_remove_export (store, recipe);
                 exporter->recipes = g_list_remove (exporter->recipes, recipe);
                 g_object_unref (recipe);
                 gtk_widget_set_opacity (image, 0.0);
         }
         else {
+                gr_recipe_store_add_export (store, recipe);
                 exporter->recipes = g_list_append (exporter->recipes, g_object_ref (recipe));
                 gtk_widget_set_opacity (image, 1.0);
         }
@@ -729,17 +755,22 @@ void
 gr_recipe_exporter_export (GrRecipeExporter *exporter,
                            GrRecipe         *recipe)
 {
-        GList *l;
+        GrRecipeStore *store;
+        const char **keys;
+        int i;
 
-        // TODO: listen for ::recipe-removed and filter out the list
-        for (l = exporter->recipes; l; l = l->next) {
-                if (l->data == (gpointer)recipe)
-                        goto dialog;
+        store = gr_recipe_store_get ();
+        gr_recipe_store_add_export (store, recipe);
+        keys = gr_recipe_store_get_export_list (store);
+
+        g_list_free_full (exporter->recipes, g_object_unref);
+        exporter->recipes = NULL;
+
+        for (i = 0; keys[i]; i++) {
+                g_autoptr(GrRecipe) r = gr_recipe_store_get_recipe (store, keys[i]);
+                exporter->recipes = g_list_prepend (exporter->recipes, g_object_ref (r));
         }
 
-        exporter->recipes = g_list_append (exporter->recipes, g_object_ref (recipe));
-
-dialog:
         show_export_dialog (exporter);
 }
 
@@ -764,7 +795,7 @@ collect_all_recipes (GrRecipeExporter *exporter)
         guint length;
         int i;
 
-        store = gr_app_get_recipe_store (GR_APP (g_application_get_default ()));
+        store = gr_recipe_store_get ();
         keys = gr_recipe_store_get_recipe_keys (store, &length);
         for (i = 0; keys[i]; i++) {
                 g_autoptr(GrRecipe) recipe = gr_recipe_store_get_recipe (store, keys[i]);
@@ -779,7 +810,7 @@ gr_recipe_exporter_export_all (GrRecipeExporter *exporter,
 {
         collect_all_recipes (exporter);
 
-        g_message ("Exporting %d recipes", g_list_length (exporter->recipes));
+        g_info ("Exporting %d recipes", g_list_length (exporter->recipes));
 
         if (exporter->recipes == NULL)
                 return;
