@@ -32,7 +32,6 @@
 #include "gr-chef.h"
 #include "gr-recipe.h"
 #include "gr-recipe-store.h"
-#include "gr-app.h"
 #include "gr-utils.h"
 #include "gr-recipe-tile.h"
 #include "gr-chef-tile.h"
@@ -83,6 +82,8 @@ struct _GrRecipeImporter
         char *recipe_notes;
         char **recipe_paths;
         int recipe_serves;
+        int recipe_spiciness;
+        int recipe_default_image;
         GrDiets recipe_diets;
         GDateTime *recipe_ctime;
         GDateTime *recipe_mtime;
@@ -285,7 +286,7 @@ import_recipe (GrRecipeImporter *importer)
         g_autofree char *id = NULL;
         const char *author;
 
-        store = gr_app_get_recipe_store (GR_APP (g_application_get_default ()));
+        store = gr_recipe_store_get ();
 
         images = gr_image_array_new ();
         if (importer->recipe_paths) {
@@ -322,6 +323,8 @@ import_recipe (GrRecipeImporter *importer)
                       "instructions", importer->recipe_instructions,
                       "notes", importer->recipe_notes,
                       "serves", importer->recipe_serves,
+                      "spiciness", importer->recipe_spiciness,
+                      "default-image", importer->recipe_default_image,
                       "diets", importer->recipe_diets,
                       "images", images,
                       "ctime", importer->recipe_ctime,
@@ -346,13 +349,13 @@ recipe_dialog_response (GtkWidget        *dialog,
                         GrRecipeImporter *importer)
 {
         if (response_id == GTK_RESPONSE_CANCEL) {
-                g_message ("Not importing recipe %s", importer->recipe_name);
+                g_info ("Not importing recipe %s", importer->recipe_name);
                 gtk_widget_destroy (dialog);
         }
         else {
                 g_free (importer->recipe_name);
                 importer->recipe_name = g_strdup (g_object_get_data (G_OBJECT (dialog), "name"));
-                g_message ("Renaming recipe to %s while importing", importer->recipe_name);
+                g_info ("Renaming recipe to %s while importing", importer->recipe_name);
                 gtk_widget_destroy (dialog);
                 if (!import_recipe (importer))
                         return;
@@ -372,7 +375,7 @@ recipe_name_changed (GtkEntry         *entry,
         GtkWidget *dialog;
         g_autoptr(GrRecipe) recipe = NULL;
 
-        store = gr_app_get_recipe_store (GR_APP (g_application_get_default ()));
+        store = gr_recipe_store_get ();
 
         name = gtk_entry_get_text (entry);
         author = (const char *)g_hash_table_lookup (importer->chef_id_map, importer->recipe_author);
@@ -431,7 +434,7 @@ import_next_recipe (GrRecipeImporter *importer)
         g_autoptr(GError) error = NULL;
         const char *id;
 
-        store = gr_app_get_recipe_store (GR_APP (g_application_get_default ()));
+        store = gr_recipe_store_get ();
 
 next:
         importer->current_recipe++;
@@ -461,6 +464,8 @@ next:
         importer->recipe_instructions = key_file_get_string (importer->recipes_keyfile, id, "Instructions");
         importer->recipe_notes = key_file_get_string (importer->recipes_keyfile, id, "Notes");
         importer->recipe_serves = g_key_file_get_integer (importer->recipes_keyfile, id, "Serves", &error);
+        importer->recipe_spiciness = g_key_file_get_integer (importer->recipes_keyfile, id, "Spiciness", &error);
+        importer->recipe_default_image = g_key_file_get_integer (importer->recipes_keyfile, id, "DefaultImage", &error);
         handle_or_clear_error (error);
         importer->recipe_diets = g_key_file_get_integer (importer->recipes_keyfile, id, "Diets", &error);
         handle_or_clear_error (error);
@@ -491,7 +496,7 @@ next:
 
         recipe = gr_recipe_store_get_recipe (store, importer->recipe_id);
         if (!recipe) {
-                g_message ("Recipe %s not yet known; importing", importer->recipe_id);
+                g_info ("Recipe %s not yet known; importing", importer->recipe_id);
                 if (!import_recipe (importer))
                         return FALSE;
                 goto next;
@@ -533,7 +538,7 @@ import_chef (GrRecipeImporter *importer)
         g_autoptr(GrChef) chef = NULL;
         g_autoptr(GError) error = NULL;
 
-        store = gr_app_get_recipe_store (GR_APP (g_application_get_default ()));
+        store = gr_recipe_store_get ();
 
         if (importer->chef_image_path) {
                 char *new_path;
@@ -575,7 +580,7 @@ find_unused_chef_id (const char *base)
         GrRecipeStore *store;
         int i;
 
-        store = gr_app_get_recipe_store (GR_APP (g_application_get_default ()));
+        store = gr_recipe_store_get ();
 
         for (i = 0; i < 100; i++) {
                 g_autofree char *new_id = NULL;
@@ -610,7 +615,7 @@ chef_dialog_response (GtkWidget        *dialog,
                       GrRecipeImporter *importer)
 {
         if (response_id == GTK_RESPONSE_CANCEL) {
-                g_message ("Chef %s known after all; not importing", importer->chef_id);
+                g_info ("Chef %s known after all; not importing", importer->chef_id);
                 gtk_widget_destroy (dialog);
         }
         else {
@@ -628,7 +633,7 @@ chef_dialog_response (GtkWidget        *dialog,
                 importer->chef_fullname = g_strdup (gtk_entry_get_text (GTK_ENTRY (importer->new_chef_fullname)));
                 importer->chef_description = get_text_view_text (GTK_TEXT_VIEW (importer->new_chef_description));
 
-                g_message ("Renaming chef to %s while importing", importer->chef_id);
+                g_info ("Renaming chef to %s while importing", importer->chef_id);
                 gtk_widget_destroy (dialog);
                 if (!import_chef (importer))
                         return;
@@ -702,7 +707,7 @@ import_next_chef (GrRecipeImporter *importer)
         g_autoptr(GrChef) chef = NULL;
         GrRecipeStore *store;
 
-        store = gr_app_get_recipe_store (GR_APP (g_application_get_default ()));
+        store = gr_recipe_store_get ();
 
 next:
         importer->current_chef++;
@@ -721,7 +726,7 @@ next:
         g_hash_table_insert (importer->chef_id_map, g_strdup (importer->chef_id), g_strdup (id));
         chef = gr_recipe_store_get_chef (store, id);
         if (!chef) {
-                g_message ("Chef %s not yet known; importing", id);
+                g_info ("Chef %s not yet known; importing", id);
                 import_chef (importer);
                 goto next;
         }
@@ -729,7 +734,7 @@ next:
         if (g_strcmp0 (importer->chef_fullname, gr_chef_get_fullname (chef)) == 0 &&
             g_strcmp0 (importer->chef_name, gr_chef_get_name (chef)) == 0 &&
             g_strcmp0 (importer->chef_description, gr_chef_get_description (chef)) == 0) {
-                g_message ("Chef %s already known, not importing", id);
+                g_info ("Chef %s already known, not importing", id);
                 goto next;
         }
 
